<?php

namespace Drupal\site_analysis;

use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class ContentAnalysis extends Analysis {

  public function generateContentReport(): array {
    $config = $this->configFactory->get('site_analysis.settings');
    $report = [];

    if ($config->get('check_bundles')) {
      $report['content_types'] = $this->getContentTypes();
    }

    if ($config->get('node_count')) {
      $report['node_count'] = $this->getNodeCount();
    }

    if ($config->get('duplicate_titles')) {
      $report['duplicate_titles'] = $this->getDuplicateTitles();
    }

    return $report;
  }

  private function getContentTypes(): array {
    $contentTypes = \Drupal::entityTypeManager()
      ->getStorage('node_type')
      ->loadMultiple();
    return array_map(fn($type) => [
      'id' => $type->id(),
      'label' => $type->label(),
    ], $contentTypes);
  }

  private function getNodeCount(): array {
    $bundleIds = array_column($this->getContentTypes(), 'id');
    $count = [];

    foreach ($bundleIds as $bundle) {
      $count[$bundle] = \Drupal::entityQuery('node')
        ->accessCheck(FALSE)
        ->condition('type', $bundle)
        ->count()
        ->execute();
    }

    return $count;
  }

  public function getDuplicateTitles(): array {
    $query = \Drupal::database()->select('node_field_data', 'n');
    $query->fields('n', ['title']);
    $query->addExpression('COUNT(n.title)', 'duplicate_count');
    $query->condition('n.status', 1);
    $query->groupBy('n.title');
    $query->having('COUNT(n.title) > 1');

    $duplicateTitles = $query->execute()->fetchAllKeyed();

    $titles = [];
    foreach ($duplicateTitles as $title => $count) {
      $titles[] = ['title' => $title, 'count' => $count];
    }

    return $titles;
  }

}
