<?php

namespace Drupal\site_analysis;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\views\Views;
use Symfony\Component\DependencyInjection\ContainerInterface;

class FieldAnalysis extends Analysis {

  public function generateFieldReport() {
    $config = $this->configFactory->get('site_analysis.settings');
    $report = [];

    if ($config->get('unused_fields')) {
      $report['unused_fields'] = $this->getUnusedFields();
    }

    return $report;
  }

  public function getUnusedFields(): array {
    $fields = FieldStorageConfig::loadMultiple();

    $unused_fields = [];

    foreach ($fields as $field) {
      $entity_type = $field->getTargetEntityTypeId();
      $field_name = $field->getName();
      $bundles = implode(', ', array_keys($field->getBundles()));

      $used_in_views = $this->isFieldUsedInViews($field_name);
      $used_in_code = $this->isFieldUsedInCustomCode($field_name);

      $unused_fields[] = [
        $field_name,
        $entity_type,
        $bundles,
        $used_in_views,
        $used_in_code,
      ];
    }

    return $unused_fields;
  }

  protected function isFieldUsedInViews($field_name): bool {
    $views = Views::getAllViews();
    foreach ($views as $view) {
      $view_display = $view->get('display');
      foreach ($view_display as $display) {
        if (isset($display['display_options'])) {
          $display_options = $display['display_options'];
          foreach ([
            'fields',
            'filters',
            'sorts',
            'relationships',
          ] as $section) {
            if (!empty($display_options[$section])) {
              foreach ($display_options[$section] as $option) {
                if (isset($option['field']) && $option['field'] === $field_name) {
                  return TRUE;
                }
              }
            }
          }
        }
      }
    }
    return FALSE;
  }

  protected function isFieldUsedInCustomCode($field_name): bool {
    $escaped_field = escapeshellarg($field_name);
    $command = "grep -r --include='*.(php|module|install)' $escaped_field ../.. 2>/dev/null";

    $output = shell_exec($command);
    return !empty($output) ? TRUE : FALSE;
  }

}
