<?php

namespace Drupal\site_analysis\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class SiteAnalysisSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['site_analysis.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'site_analysis_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['site_analysis'] = [
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-content',
    ];

    $form['content'] = [
      '#type' => 'details',
      '#title' => $this->t('Content'),
      '#group' => 'site_analysis',
      'content_text' => [
        '#type' => 'item',
        '#title' => $this->t('Content Analysis'),
        '#description' => $this->t('Reports all content types.'),
      ],
      'check_bundles' => [
        '#type' => 'checkbox',
        '#title' => $this->t('Content Types'),
        '#description' => $this->t('Reports all content types.'),
        '#default_value' => $this->config('site_analysis.settings')
          ->get('check_bundles'),
      ],
      'node_count' => [
        '#type' => 'checkbox',
        '#title' => $this->t('Node Count'),
        '#description' => $this->t('Reports all number of nodes per content type.'),
        '#default_value' => $this->config('site_analysis.settings')
          ->get('node_count'),
      ],
      'duplicate_titles' => [
        '#type' => 'checkbox',
        '#title' => $this->t('Duplicate Titles'),
        '#description' => $this->t('Reports nodes with duplicate titles.'),
        '#default_value' => $this->config('site_analysis.settings')
          ->get('duplicate_titles'),
      ],
    ];

    $form['fields'] = [
      '#type' => 'details',
      '#title' => $this->t('Fields Analysis'),
      '#group' => 'site_analysis',
      'fields_text' => [
        '#type' => 'item',
        '#title' => $this->t('Fields Analysis'),
        '#description' => $this->t('Reports all fields.'),
      ],
      'unused_fields' => [
        '#type' => 'checkbox',
        '#title' => $this->t('Fields'),
        '#description' => $this->t('Reports all unused fields.'),
        '#default_value' => $this->config('site_analysis.settings')
          ->get('unused_fields'),
      ],
    ];

    // Check if module is installed
    if (\Drupal::moduleHandler()->moduleExists('paragraphs')) {
      $form['paragraphs'] = [
        '#type' => 'details',
        '#title' => $this->t('Paragraphs Analysis'),
        '#group' => 'site_analysis',
        'paragraphs_text' => [
          '#type' => 'item',
          '#title' => $this->t('Paragraphs Analysis'),
          '#description' => $this->t('Reports all paragraphs.'),
        ],
        'paragraph_count' => [
          '#type' => 'checkbox',
          '#title' => $this->t('Paragraphs Count'),
          '#description' => $this->t('Reports all paragraphs and their usage.'),
          '#default_value' => $this->config('site_analysis.settings')
            ->get('paragraph_count'),
        ],
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('site_analysis.settings');
    $ignore = [
      'site_analysis__active_tab',
      'submit',
      'form_build_id',
      'form_token',
      'form_id',
      'op',
    ];
    foreach ($form_state->getValues() as $field => $value) {
      if (in_array($field, $ignore) || str_contains($field, '_text')) {
        continue;
      }
      $config->set($field, $value);
    }
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
